==> 2025-11-13-11-48-27-dify-1.9.2.zip: dify-1.9.2/web/app/components/workflow/hooks/use-workflow-run-event/use-workflow-agent-log.ts <==
import { useCallback } from 'react'
import { produce } from 'immer'
import type { AgentLogResponse } from '@/types/workflow'
import { useWorkflowStore } from '@/app/components/workflow/store'

export const useWorkflowAgentLog = () => {
  const workflowStore = useWorkflowStore()

  const handleWorkflowAgentLog = useCallback((params: AgentLogResponse) => {
    const { data } = params
    const {
      workflowRunningData,
      setWorkflowRunningData,
    } = workflowStore.getState()

    setWorkflowRunningData(produce(workflowRunningData!, (draft) => {
      const currentIndex = draft.tracing!.findIndex(item => item.node_id === data.node_id)
      if (currentIndex > -1) {
        const current = draft.tracing![currentIndex]

        if (current.execution_metadata) {
          if (current.execution_metadata.agent_log) {
            const currentLogIndex = current.execution_metadata.agent_log.findIndex(log => log.message_id === data.message_id)
            if (currentLogIndex > -1) {
              current.execution_metadata.agent_log[currentLogIndex] = {
                ...current.execution_metadata.agent_log[currentLogIndex],
                ...data,
              }
            }
            else {
              current.execution_metadata.agent_log.push(data)
            }
          }
          else {
            current.execution_metadata.agent_log = [data]
          }
        }
        else {
          current.execution_metadata = {
            agent_log: [data],
          } as any
        }
      }
    }))
  }, [workflowStore])

  return {
    handleWorkflowAgentLog,
  }
}

==> 2025-11-24-10-54-20-dify-1.1.3.zip: dify-1.1.3/web/app/components/workflow/hooks/use-workflow-run-event/use-workflow-agent-log.ts <==
import { useCallback } from 'react'
import produce from 'immer'
import type { AgentLogResponse } from '@/types/workflow'
import { useWorkflowStore } from '@/app/components/workflow/store'

export const useWorkflowAgentLog = () => {
  const workflowStore = useWorkflowStore()

  const handleWorkflowAgentLog = useCallback((params: AgentLogResponse) => {
    const { data } = params
    const {
      workflowRunningData,
      setWorkflowRunningData,
    } = workflowStore.getState()

    setWorkflowRunningData(produce(workflowRunningData!, (draft) => {
      const currentIndex = draft.tracing!.findIndex(item => item.node_id === data.node_id)
      if (currentIndex > -1) {
        const current = draft.tracing![currentIndex]

        if (current.execution_metadata) {
          if (current.execution_metadata.agent_log) {
            const currentLogIndex = current.execution_metadata.agent_log.findIndex(log => log.id === data.id)
            if (currentLogIndex > -1) {
              current.execution_metadata.agent_log[currentLogIndex] = {
                ...current.execution_metadata.agent_log[currentLogIndex],
                ...data,
              }
            }
            else {
              current.execution_metadata.agent_log.push(data)
            }
          }
          else {
            current.execution_metadata.agent_log = [data]
          }
        }
        else {
          current.execution_metadata = {
            agent_log: [data],
          } as any
        }
      }
    }))
  }, [workflowStore])

  return {
    handleWorkflowAgentLog,
  }
}
